SET NOCOUNT ON

use JitbitHelpDesk
go
--creating tables
CREATE TABLE [dbo].[hdCategories] (
	[CategoryID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] nvarchar (250) NOT NULL,
	[SectionID] int NULL,
	[InstanceID] int NOT NULL DEFAULT(0),
	[ForTechsOnly] bit NOT NULL DEFAULT (0),
	[ForSpecificUsers] bit NOT NULL DEFAULT (0),
	OrderByNumber int NOT NULL DEFAULT 1,
	FromAddress varchar(255) NULL,
	KBOnly bit NOT NULL DEFAULT 0,
	FromAddressInReplyTo bit NOT NULL DEFAULT 1,
	Notes nvarchar(max) NULL,
	FromName varchar(255) NULL,
	Disabled bit not null default 0
)
GO

CREATE TABLE [dbo].[hdSections] (
	[SectionID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] nvarchar (250) NOT NULL,
	[InstanceID] int NOT NULL DEFAULT(0),
	OrderByNumber int NOT NULL DEFAULT 1
)
GO

CREATE TABLE [dbo].[Instances] (
	[InstanceID] int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] varchar (100) NOT NULL,
	[CustomerID] int NOT NULL,
	ValidTill datetime NOT NULL,
	CustomDomain varchar(100) NULL,
	WidgetInstalled bit NOT NULL DEFAULT 0
)
GO

CREATE TABLE [dbo].[CustomHolidays] (
	[InstanceID] int NOT NULL,
	[Holiday] date NOT NULL
)
GO
--now add complex primary key in [[CustomHolidays]] table
ALTER TABLE [dbo].[CustomHolidays] WITH NOCHECK ADD 
	CONSTRAINT [PK_CustomHolidays] PRIMARY KEY CLUSTERED 
	(
		[InstanceID], [Holiday]
	)
GO

CREATE TABLE [dbo].[hdCategoryPermissions] (
	[UserID] [int] NOT NULL,
	[CategoryID] [int] NOT NULL 
)
GO

--now add complex primary key in [hdCategoryPermissions] table
ALTER TABLE [dbo].[hdCategoryPermissions] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdCategoryPermissions] PRIMARY KEY CLUSTERED 
	(
		[UserID],
		[CategoryID]
	)
GO


CREATE TABLE [dbo].[hdCategorySubmitPermissions] (
	[UserID] [int] NOT NULL ,
	[CategoryID] [int] NOT NULL 
)
GO
--now add complex primary key in [hdCategoryPermissions] table
ALTER TABLE [dbo].[hdCategorySubmitPermissions] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdCategorySubmitPermissions] PRIMARY KEY CLUSTERED 
	(
		[UserID],
		[CategoryID]
	)
GO

CREATE TABLE [dbo].[hdCategorySubmitPermissionsByCompany] (
	[CompanyID] [int] NOT NULL ,
	[CategoryID] [int] NOT NULL 
)
GO
--now add complex primary key in [hdCategoryPermissions] table
ALTER TABLE [dbo].[hdCategorySubmitPermissionsByCompany] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdCategorySubmitPermissionsByCompany] PRIMARY KEY CLUSTERED 
	(
		[CompanyID],
		[CategoryID]
	)
GO

CREATE TABLE [dbo].[hdComments] (
	[CommentID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[IssueID] [int] NOT NULL ,
	[CommentDate] [datetime] NOT NULL DEFAULT (getdate()),
	[UserID] [int] NULL ,
	[Body] nvarchar(max) NOT NULL ,
	[ForTechsOnly] bit NOT NULL DEFAULT (0),
	[IsSystem] bit NOT NULL DEFAULT(0),
	Recipients nvarchar(4000) not null DEFAULT(''),
	BouncedRecipients nvarchar(3000) null,
	EmailHeaders varchar(2000) NULL,
	BounceReason varchar(1000) NULL,
	InstanceID int null,
	FTS_filetype As '.htm',
	FTS_Body as 0xFFFE + CAST((N'InstanceID' + CAST(InstanceID as nvarchar(max)) + N' ' + Body) as VARBINARY(MAX))
)
GO

CREATE TABLE [dbo].[hdCommentTemplates] (
	[TemplateID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[Name] nvarchar(255) NULL,
	[Body] nvarchar(max) NOT NULL,
	GroupID int NULL
)
GO

CREATE TABLE [dbo].[CommentTemplateGroups] (
	GroupID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL,
	[Name] nvarchar(100) NOT NULL
)
GO

CREATE TABLE [dbo].[CommentTemplateCategories] (
	[TemplateID] int NOT NULL,
	[CategoryID] int NOT NULL
)
ALTER TABLE CommentTemplateCategories WITH NOCHECK ADD CONSTRAINT PK_CommentTemplateCategories PRIMARY KEY CLUSTERED (
	TemplateID,
	CategoryID
)

CREATE TABLE [dbo].[hdIssues] (
	[IssueID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[IssueDate] [datetime] NOT NULL DEFAULT (getdate()),
	[UserID] [int] NOT NULL ,
	[CategoryID] [int] NOT NULL ,
	[StartDate] datetime null,
	[ResolvedDate] [datetime] NULL ,
	[AssignedToUserID] [int] NULL ,
	[Subject] [nvarchar] (1000) NOT NULL ,
	[Body] nvarchar(max) NOT NULL ,
	[UpdatedByUser] [bit] NOT NULL DEFAULT (0),
	[UpdatedByPerformer] [bit] NOT NULL DEFAULT (0),
	[UpdatedForTechView] [bit] NOT NULL DEFAULT (0),
	[StatusID] [int] NOT NULL DEFAULT (1),
	[Priority] smallint NOT NULL DEFAULT (0),
	[TimeSpentInSeconds] int NOT NULL DEFAULT(0),
	[LastUpdated] datetime NOT NULL DEFAULT(getdate()),
	DueDate datetime NULL,
	Origin smallint NOT NULL default(0),
	FTS_filetype As '.htm',
	FTS_Body as 0xFFFE + CAST((Subject + N' InstanceID' + CAST(InstanceID as nvarchar(max)) + N' ' + Body) as VARBINARY(MAX)),
	TimesReopened int NOT NULL DEFAULT 0,
	Rating tinyint NOT NULL DEFAULT 0,
	LastUpdatedByUserID int NULL
)
GO

CREATE TABLE [dbo].[hdSharedIssues] (IssueID int NOT NULL PRIMARY KEY)

CREATE TABLE [dbo].[KBArticles] (
	[ArticleID] [int] NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[CategoryID] [int] NOT NULL ,
	[Subject] [nvarchar] (1000) NOT NULL ,
	[Body] nvarchar(max) NOT NULL,
	[ForTechsOnly] [bit] NOT NULL DEFAULT (0),
	[OrderByNumber] int NOT NULL DEFAULT (1),
	DateCreated datetime NULL DEFAULT (getdate()),
	LastUpdated datetime NULL DEFAULT (getdate()),
	AIMeta nvarchar(max) NULL,
	CreatedByUserID int NULL,
	LastUpdatedByUserID int NULL,
	GPTIndexed bit not null default(0)
)
GO

CREATE TABLE [dbo].[KBSearchLog] (
	SearchID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL DEFAULT 0,
	[Date] datetime NOT NULL,
	Query nvarchar(200),
	NumResults int NOT NULL DEFAULT 0
)
GO

CREATE TABLE [dbo].[KBViewLog] (
	ArticleID int NOT NULL,
	[Date] date NOT NULL,
	NumViews int NOT NULL DEFAULT 0
)
ALTER TABLE KBViewLog WITH NOCHECK ADD
	CONSTRAINT [PK_KBViewLog] PRIMARY KEY CLUSTERED (ArticleID, [Date])
GO

CREATE TABLE dbo.KBSubscribers (
	CategoryID int NOT NULL,
	UserID int NOT NULL
)
ALTER TABLE KBSubscribers WITH NOCHECK ADD
	CONSTRAINT [PK_KBSubscribers] PRIMARY KEY CLUSTERED (CategoryID, UserID)
GO

CREATE TABLE dbo.KBArticleSubscribers (
	ArticleID int NOT NULL,
	UserID int NOT NULL
)
ALTER TABLE KBArticleSubscribers WITH NOCHECK ADD
	CONSTRAINT [PK_KBArticleSubscribers] PRIMARY KEY CLUSTERED (ArticleID, UserID)
GO

CREATE TABLE [dbo].[hdOnBehalfIssues] (
	[IssueID] [int] NOT NULL PRIMARY KEY,
	[SubmittedByUserID] int NOT NULL
)
GO

CREATE TABLE dbo.hdMergedIssues (
	[IssueID] int NOT NULL,
	[IssueMergedID] int NOT NULL
)
ALTER TABLE hdMergedIssues WITH NOCHECK ADD CONSTRAINT [PK_hdMergedIssues] PRIMARY KEY CLUSTERED (
	IssueID,
	IssueMergedID
)
GO

CREATE TABLE [dbo].[hdCustomFields] (
	[FieldID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] [int] NOT NULL,
	[Type] [int] NOT NULL,
	[FieldName] nvarchar(100) NOT NULL,
	[Mandatory] bit NOT NULL DEFAULT (0),
	[ShowInGrid] bit NOT NULL DEFAULT (1),
	[OrderByNumber] int NOT NULL DEFAULT (100),
	UsageType int NOT NULL DEFAULT 1,
	AccessType tinyint not null default(0),
	ParentFieldID int null --for dependent dropdowns
)
GO

CREATE TABLE dbo.hdIssueSchedule (
	IssueID int NOT NULL PRIMARY KEY,
	FreqType int NOT NULL,
	FirstRecurrenceDate datetime NOT NULL,
	PrevRepeatsCount int NOT NULL DEFAULT(0),
	ReopenOriginal bit not null default 0,
	LastRecurrenceDate datetime NULL
)
GO

CREATE TABLE dbo.hdScheduledIssues (
	ScheduledIssueID int NOT NULL PRIMARY KEY,
	OriginalIssueID int NOT NULL
)
GO

CREATE TABLE [dbo].[hdCustomFieldValues] (
	[IssueID] [int] NOT NULL,
	[FieldID] [int] NOT NULL,
	[Value] sql_variant NOT NULL,
	[OptionID] int NULL
)
GO
ALTER TABLE [dbo].[hdCustomFieldValues] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdCustomFieldValues]PRIMARY KEY CLUSTERED 
	(
		[IssueID],
		[FieldID]
	)
GO

CREATE TABLE [dbo].hdCustomFieldTextValues (
	IssueID int NOT NULL PRIMARY KEY,
	CustomFieldsText nvarchar(max)
)
	
exec sp_executesql N'
CREATE TRIGGER updCfText ON dbo.hdCustomFieldValues AFTER DELETE, UPDATE, INSERT
as begin
	--exit if non-text fields are updated
	if not exists (select 1 from inserted join hdCustomFields cf on cf.FieldID=inserted.FieldID where cf.Type in (1,3,5))
		return;

	--delete removed
	delete from hdCustomFieldTextValues where issueid in (select issueid from deleted union all select issueid from inserted)

	--insert (rewrite the data)
	BEGIN TRY --JFDI-pattern
		insert into hdCustomFieldTextValues(IssueID, CustomFieldsText)
		select IssueID, N''InstanceID'' + CAST(hdCustomFields.InstanceID as nvarchar(max)) + (select '' '' + cast([Value] as nvarchar(max)) from hdCustomFieldValues WITH(NOLOCK) WHERE IssueID = cfv.IssueID FOR XML PATH(''''))
		from hdCustomFieldValues cfv WITH(NOLOCK)
		join hdCustomFields on cfv.FieldID = hdCustomFields.FieldID
		where hdCustomFields.Type in (1,3,5) and IssueID in (SELECT IssueID from inserted)
		group by IssueID, hdCustomFields.InstanceID
	END TRY
	BEGIN CATCH
		IF ERROR_NUMBER() <> 2627 AND ERROR_NUMBER() <> 2601
			THROW 
	END CATCH
end'


CREATE TABLE [dbo].[hdCustomFieldValuesForAssets] (
	[ItemID] [int] NOT NULL,
	[FieldID] [int] NOT NULL,
	[Value] sql_variant NOT NULL,
	[OptionID] int NULL
)
GO
ALTER TABLE [dbo].[hdCustomFieldValuesForAssets] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdCustomFieldValuesForAssets] PRIMARY KEY CLUSTERED 
	(
		[ItemID],
		[FieldID]
	)
GO

CREATE TABLE [dbo].[hdCustomFieldValuesForUsers] (
	[UserID] [int] NOT NULL,
	[FieldID] [int] NOT NULL,
	[Value] sql_variant NOT NULL,
	[OptionID] int NULL
)
GO
ALTER TABLE [dbo].[hdCustomFieldValuesForUsers] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdCustomFieldValuesForUsers] PRIMARY KEY CLUSTERED 
	(
		[UserID],
		[FieldID]
	)
GO

CREATE TABLE [dbo].[hdCustomFieldValuesForCompanies] (
	[CompanyID] [int] NOT NULL,
	[FieldID] [int] NOT NULL,
	[Value] sql_variant NOT NULL,
	[OptionID] int NULL
)
GO
ALTER TABLE [dbo].[hdCustomFieldValuesForCompanies] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdCustomFieldValuesForCompanies] PRIMARY KEY CLUSTERED 
	(
		[CompanyID],
		[FieldID]
	)
GO

CREATE TABLE [dbo].[IssueEmailMessageID] (
	IssueID int NOT NULL PRIMARY KEY,
	MessageID nvarchar(1000) NOT NULL
)
GO


CREATE TABLE [dbo].[hdTags] (
	TagID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[Name] nvarchar(200) NOT NULL,
	InstanceID int NOT NULL
)
GO

CREATE TABLE [dbo].[hdIssueTags] (
	TagID int NOT NULL,
	IssueID int NOT NULL
)
ALTER TABLE hdIssueTags WITH NOCHECK ADD CONSTRAINT [PK_hdIssueTags] PRIMARY KEY CLUSTERED (TagID,IssueID)
GO

CREATE TABLE [dbo].[KBArticleTags] (
	TagID int NOT NULL,
	ArticleID int NOT NULL
)
ALTER TABLE KBArticleTags WITH NOCHECK ADD CONSTRAINT [PK_KBArticleTags] PRIMARY KEY CLUSTERED (TagID,ArticleID)
GO

CREATE TABLE [dbo].[IdeaTags] (
	TagID int NOT NULL,
	IdeaID int NOT NULL
)
ALTER TABLE IdeaTags WITH NOCHECK ADD CONSTRAINT [PK_IdeaTags] PRIMARY KEY CLUSTERED (TagID,IdeaID)
GO

CREATE TABLE [dbo].[AssetTags] (
	TagID int NOT NULL,
	AssetID int NOT NULL
)
ALTER TABLE AssetTags WITH NOCHECK ADD CONSTRAINT [PK_AssetTags] PRIMARY KEY CLUSTERED (TagID,AssetID)
GO

CREATE TABLE [dbo].[hdCustomFieldOptions] (
	[OptionID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[FieldID] [int] NOT NULL,
	[OptionValue] nvarchar(500) NOT NULL,
	IsDefault bit not null default 0,
	OrderByNumber int NOT NULL DEFAULT 1,
	IsDisabled bit not null default 0,
	ParentOptionID int null
)
GO

CREATE TABLE [dbo].[CustomFieldCategories] (
	[FieldID] [int] NOT NULL,
	[CategoryID] int NOT NULL
)
ALTER TABLE CustomFieldCategories WITH NOCHECK ADD CONSTRAINT [PK_CustomFieldCategories] PRIMARY KEY CLUSTERED (
	FieldID,
	CategoryID
)

--KB suggestions cache
CREATE TABLE [dbo].[KBSuggestionsCache] (
	IssueID int NOT NULL,
	ArticleID int NOT NULL
)
ALTER TABLE KBSuggestionsCache WITH NOCHECK ADD CONSTRAINT [PK_KBSuggestionsCache] PRIMARY KEY CLUSTERED (
	IssueID,
	ArticleID
)

CREATE TABLE [dbo].[hdSettings] (
	[InstanceID] int NOT NULL DEFAULT(0) PRIMARY KEY,
	[EmailNotificationsEnabled] [bit] NOT NULL DEFAULT (0),
	[SMTPServer] varchar (100) NULL ,
	[SMTPAuthRequired] [bit] NOT NULL  DEFAULT (0),
	[SMTPUserName] varchar (50) NULL ,
	[SMTPPassword] varchar (500) NULL ,
	[SMTPUseSSL] bit NOT NULL  DEFAULT (0) ,
	[FromAddress] varchar (150) NULL ,
	ReplyToAddress varchar (50) NULL,
	FromName nvarchar(50) NULL,
	UseFromNameForUserOriginatedMsgs bit not null DEFAULT 0,
	AllowUserRegistration bit NOT NULL  DEFAULT (1),
	SMTPPort int NOT NULL DEFAULT (25),
	MailCheckerNewIssuesCategoryID int NOT NULL DEFAULT (1),
	MailCheckerAllowUnregisteredUsers bit NOT NULL DEFAULT (1),
	RestrictIssueDeletion bit NOT NULL DEFAULT (0),
	Lang varchar (10) NOT NULL DEFAULT ('en-US'),
	RestrictIssueClosing bit NOT NULL DEFAULT (0),
	NewIssuesDefaultCategoryID int NOT NULL DEFAULT 1,
	AllowGuestSubmission bit default 1,
	AllowAnonymousKBAccess bit default 1,
	SeeEveryonesIssues bit default 0,
	UseDefaultSmtp bit default 0,
	HeaderBGColor char(6) NOT NULL DEFAULT('34383E'),
	MenuBarBGColor char(6) NOT NULL DEFAULT('4C5B6B'),
	HeaderTextColor char(6) NOT NULL DEFAULT('FFFFFF'),
	LogoImage [image] NULL,
	SendTechniciansEmailOnNewIssue bit NOT NULL DEFAULT(1),
	DisableKB bit NOT NULL DEFAULT(0),
	AutoLoginSharedSecret varchar(20) NULL,
	MenuBarTextColor char(6) NOT NULL DEFAULT('C7D4E2'),
	DisableCloseNotification bit NOT NULL DEFAULT 1,
	Title nvarchar(500) NOT NULL DEFAULT 'helpdesk',
	DisableAssets bit not null default 0,
	DaysToCloseAfter int NOT NULL DEFAULT(0),
	SameCompanyUserPermission bit not null default(0),
	HidePoweredBy bit not null default(0),
	DisableAvatars bit NOT NULL DEFAULT 0,
	SendAdminEmailOnNewIssue bit NOT NULL DEFAULT 1,
	AutoAssignFirstReplier bit not null default 1,
	NotifyAllTechsOnReply bit NOT NULL default 0,
	NewTicketNote nvarchar(max) NULL,
	CustomCSS varchar(max) NULL,
	DisableAutoTimer bit not null default 0,
	DontAddCCToSubscribers bit not null default 0,
	WorkHourFrom int null,
	WorkHourTo int null,
	EmailOtherTechsOnTakeover bit not null default 0,
	EnableSaml bit not null default 0,
	SamlEndpoint varchar(200),
	SamlCertificate varchar(4500),
	DisableTicketConfirmationNotification bit NOT NULL DEFAULT 0,
	TimezoneID varchar(50) NOT NULL default('Eastern Standard Time'),
	ActiveTabTextColor char(6) NOT NULL DEFAULT('FFFFFF'),
	RemoteLoginURL varchar(500) NULL,
	NoAttachmentsInNotifications bit NOT NULL DEFAULT 0,
	DisableAutologinLinks bit NOT NULL DEFAULT 0,
	ExtractOriginalSenderFromFwd bit NOT NULL DEFAULT 1,
	FaviconImage [image] NULL,
	EnableGoogleLogin bit NOT NULL DEFAULT 0,
	DisableUsernameEmailEdit bit NOT NULL DEFAULT 0,
	KBTitle nvarchar(max) NULL,
	KBCss varchar(max) NULL,
	KBHeadCode varchar(max) NULL,
	SendTechEmailOnKBUpdate bit not null default 0,
	HideLoginButtonWhenSAML bit not null default 0,
	CustomJS varchar(max) NULL,
	EnableMultiAsssign bit not null default 0,
	LogoURL varchar(100) NULL,
	DaysToAllowReopen int NOT NULL DEFAULT 90,
	SamlEntityId varchar(200),
	KBBotEnabled bit NOT NULL default(1),
	KBHomeArticleCount tinyint NOT NULL default 5,
	DisableIdeas bit NOT NULL DEFAULT 0,
	MailcheckerUnregDomains varchar(max) NULL,
	GoogleLoginDomains varchar(1000) NULL,
	ExtractCompaniesFromDomains bit NOT NULL DEFAULT 1,
	ExtractCompaniesExceptions varchar(max) NULL,
	RestrictPriority bit NOT NULL DEFAULT 0,
	IdeasName nvarchar(100) NULL,
	TopAnnouncementHTML nvarchar(max) NULL,
	TopTechAnnouncementHTML nvarchar(max) NULL,
	TopAdminAnnouncementHTML nvarchar(max) NULL,
	MailcheckerRestrictedDomains varchar(1000) NULL,
	CcForOutgoingEmails bit NOT NULL DEFAULT 0,
	TicketMinChars tinyint NOT NULL DEFAULT 0,
	SamlButtonText nvarchar(50) NULL,
	SamlAutoRedirect bit NOT NULL DEFAULT 0,
	ReportPermissionsJson nvarchar(500) NULL,
	DisableRememberMe bit NOT NULL DEFAULT 0,
	RestrictAdminAssignment bit NOT NULL DEFAULT 0,
	DisableDefaultHolidays bit NOT NULL DEFAULT 0,
	SameDepartmentUserPermission bit not null default 0,
	DaysToDeleteAfter int not null default 0,
	TechOnlyEmailReplies bit not null default 0,
	HideSystemComments bit not null default 0,
	ThankYouText nvarchar(max) null,
	SMTPOAuthToken varchar(4000) null,
	SMTPOAuthRefreshToken varchar(4000) null,
	RequireMFA bit not null default 0,
	UselessFilterWhitelist varchar(max) null,
	AppURL varchar(200) null,
	EmailOnTakeoverIncludeAdmins bit not null default 0,
	Office365GccClientId varchar(200) null,
	Office365GccClientSecret varchar(200) null,
	DisableAutoTimerPause bit not null default 0,
	AutoTimerOnlyWhenAssigned bit not null default 0,
	AllowFreeEmails bit not null default 1,
	NewTicketLayout varbinary(50) null,
	RestrictAssetsToAdmins bit not null default 0,
	IPRestrictions varchar(max) NULL
)
GO

CREATE TABLE [dbo].[SecondaryAssignees] (
	[IssueID] int NOT NULL,
	[UserID] int NOT NULL
)
GO
--now add complex primary key in [hdIssueSubscribers] table
ALTER TABLE [dbo].[SecondaryAssignees] WITH NOCHECK ADD 
	CONSTRAINT [PK_SecondaryAssignees] PRIMARY KEY CLUSTERED ([IssueID],[UserID])
GO

CREATE TABLE [dbo].[ReportSchedule] (
	[InstanceID] int NOT NULL DEFAULT(0) PRIMARY KEY,
	ReportModelXml varchar(max) not null,
	LastSent datetime null
)

CREATE TABLE [dbo].[EmailTemplates] (
	[InstanceID] int NOT NULL DEFAULT(0),
	EmailTemplate nvarchar (max) NOT NULL DEFAULT '',
	EmailSubjectTemplate nvarchar (500) NOT NULL DEFAULT '',
	NewIssueEmailSubject nvarchar(500) NOT NULL DEFAULT '',
	NewIssueEmailTemplate nvarchar(max) NOT NULL DEFAULT '',
	WelcomeEmailSubj nvarchar (500) NOT NULL DEFAULT '',
	WelcomeEmailBody nvarchar (max) NOT NULL DEFAULT '',
	NewIssueConfirmationSubj nvarchar(500) NOT NULL DEFAULT '',
	NewIssueConfirmationBody nvarchar(max) NOT NULL DEFAULT '',
	ClosedTicketEmailTemplate nvarchar(max) NOT NULL DEFAULT '',
	ClosedTicketEmailSubject nvarchar(500) NOT NULL DEFAULT '',
	UnregUserBounceSubj nvarchar(500) NOT NULL DEFAULT '',
	UnregUserBounceBody nvarchar(max) NOT NULL DEFAULT '',
	CategoryID int NOT NULL DEFAULT 0
)
GO
ALTER TABLE [dbo].[EmailTemplates] WITH NOCHECK ADD 
	CONSTRAINT [PK_EmailTemplates] PRIMARY KEY CLUSTERED (InstanceID, CategoryID)
GO

CREATE TABLE dbo.hdPOPServers (
	ServerID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	HostName varchar (200) NULL,
	Port int NOT NULL DEFAULT (110),
	POPLogin varchar (100) NULL,
	POPPassword varchar (300) NULL,
	UseSSL bit NOT NULL DEFAULT (0),
	NewTicketsCategoryID int NULL,
	Disabled bit NOT NULL DEFAULT 0,
	ImapMarkSeenNotDelete bit NOT NULL DEFAULT 0,
	Protocol int not null DEFAULT 0,
	EwsImpersonatedUserEmail varchar(100) NULL,
	LastConnectResult varchar(200) NULL,
	Office365Token varchar(4000) null,
	Office365RefreshToken varchar(4000) null
)

CREATE TABLE [dbo].[Priorities] (
	[PriorityID] int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NULL,
	[Name] nvarchar (50) NOT NULL
)
GO

CREATE TABLE [dbo].[hdStatus] (
	[StatusID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NULL,
	[Name] nvarchar (50) NOT NULL,
	[ButtonCaption] nvarchar(50) NULL,
	[StopTimeSpent] bit not null DEFAULT (0),
	AccessType tinyint not null default(0),
	Color char(6) NULL,
	OrderByNumber int NOT NULL DEFAULT 1
)
GO

CREATE TABLE dbo.StatusCategories (
	StatusID int NOT NULL,
	[CategoryID] int NOT NULL
)
ALTER TABLE StatusCategories WITH NOCHECK ADD CONSTRAINT [PK_StatusCategories] PRIMARY KEY CLUSTERED (
	StatusID,
	CategoryID
)

CREATE TABLE [dbo].[hdUsers] (
	[UserID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[UserName] varchar (200) NOT NULL ,
	[Email] varchar (200) NOT NULL ,
	[Password] varchar (50) NOT NULL ,
	[IsAdministrator] [bit] NOT NULL DEFAULT (0),
	[FirstName] nvarchar(255) NOT NULL DEFAULT (''),
	[LastName] nvarchar(255) NOT NULL DEFAULT (''),
	CompanyID int NULL,
	[Notes] nvarchar(4000) NULL,
	[Phone] varchar(50) NULL,
	[Location] nvarchar(1000) NULL,
	[SendEmail] bit not null default 1,
	Disabled bit not null default 0,
	LastSeen datetime null,
	IPAddress varchar(50) null,
	HostName varchar(255) null,
	Lang varchar(10) NOT NULL DEFAULT(''),
	UserAgent varchar(255) null,
	[Signature] nvarchar(2000) null,
	Greeting nvarchar(500) null,
	DepartmentID int null,
	IsManager bit not null DEFAULT(0),
	IsDepartmentManager bit not null DEFAULT(0),
	TechTutorialShown bit not null default(0),
	AdminTutorialShown bit not null default(0),
	PushToken varchar(255) NULL,
	TwoFactorAuthEnabled bit NOT NULL DEFAULT (0),
	TimezoneID varchar(50) NULL,
	LastPasswordChange datetime null,
	SendNewTicketTechEmail bit not null DEFAULT (1),
	OutOfOffice bit not null default 0,
	LastLogoutDate datetime null,
	DarkMode bit not null default 0,
	DateCreated datetime NULL DEFAULT(getdate())
)
GO
--now add constraint - unique username/instance - in hdUsers table
ALTER TABLE [dbo].[hdUsers] WITH NOCHECK ADD 
	CONSTRAINT [IX_hdUsers_UniqueNameInstance] UNIQUE  NONCLUSTERED 
	(
		[UserName],
		InstanceID
	)
GO

CREATE TABLE [dbo].[UserSavedFilters] (
	UserID int NOT NULL PRIMARY KEY,
	SavedFiltersJson varchar(max) NULL
)

CREATE TABLE [dbo].[hdUserLogonHistory] (
	UserID int NOT NULL,
	LogonDate datetime NOT NULL,
	IPAddress varchar(50) NOT NULL
)
ALTER TABLE [dbo].[hdUserLogonHistory] WITH NOCHECK ADD
	CONSTRAINT [PK_hdUserLogonHistory] PRIMARY KEY CLUSTERED (UserID, LogonDate)
GO


CREATE TABLE [dbo].[UserAvatars] (
	[UserID] [int] NOT NULL PRIMARY KEY,
	[ImageData] [image] NULL,
	ImageUrl varchar(500) NULL
)

CREATE TABLE [dbo].[hdCompanies] (
	CompanyID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[Name] nvarchar(255) NOT NULL,
	Notes nvarchar(2000) NULL
)

CREATE TABLE [dbo].[CompanyDomains] (
	CompanyID int NOT NULL,
	Domain nvarchar(100) NOT NULL
)
ALTER TABLE CompanyDomains WITH NOCHECK ADD
	CONSTRAINT [PK_CompanyDomains] PRIMARY KEY CLUSTERED (CompanyID, Domain)
GO

CREATE TABLE [dbo].[Departments] (
	DepartmentID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[Name] nvarchar(255) NOT NULL
)

CREATE TABLE [dbo].[UserADSids] (
	UserID int NOT NULL PRIMARY KEY,
	UserSID varchar(100) NOT NULL
)

CREATE TABLE dbo.Ideas (
	IdeaID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	[InstanceID] int NOT NULL DEFAULT(0),
	[Subject] [nvarchar] (1000) NOT NULL ,
	[Body] nvarchar(max) NOT NULL ,
	UserID int NULL,
	Upvotes int NOT NULL default(1),
	[Status] tinyint NOT NULL default(1),
	IdeaDate datetime NOT NULL,
	UpvoteUserIds varchar(1000),
	UpvoteIpHashes varchar(1000)
)

CREATE TABLE dbo.EmailSignatures (
	UserID int NOT NULL PRIMARY KEY,
	EmailSignature varchar(max),
	MsgCount tinyint not null default 0
)

CREATE TABLE dbo.SecondaryEmails(
	UserID int NOT NULL,
	Email varchar(200) NOT NULL
)
ALTER TABLE SecondaryEmails WITH NOCHECK ADD
	CONSTRAINT [PK_SecondaryEmails] PRIMARY KEY CLUSTERED (UserID, Email)
GO

CREATE TABLE dbo.IdeaComments (
	[CommentID] [int] IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	IdeaID [int] NOT NULL ,
	[CommentDate] [datetime] NOT NULL DEFAULT (getdate()),
	[UserID] [int] NULL ,
	[Body] nvarchar(max) NOT NULL ,
	[ForTechsOnly] bit NOT NULL DEFAULT (0)
)


CREATE TABLE dbo.IdeaSubscribers (
	IdeaID int NOT NULL,
	UserID int NOT NULL
)
ALTER TABLE IdeaSubscribers WITH NOCHECK ADD
	CONSTRAINT [PK_IdeaSubscribers] PRIMARY KEY CLUSTERED (IdeaID, UserID)
GO

CREATE TABLE [dbo].[hdIssueSubscribers] (
	[IssueID] [int] NOT NULL,
	[UserID] [int] NOT NULL
)
GO
--now add complex primary key in [hdIssueSubscribers] table
ALTER TABLE [dbo].[hdIssueSubscribers] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdIssueSubscribers] PRIMARY KEY CLUSTERED 
	(
		[IssueID],
		[UserID]
	)
GO

CREATE TABLE [dbo].[hdFileAttachments](
		[FileID] [int] IDENTITY(1,1) NOT NULL PRIMARY KEY,
		[IssueID] [int] NOT NULL,
		[CommentID] int NOT NULL DEFAULT (0),
		[UserID] [int] NOT NULL,
		[FileName] nvarchar(255) NOT NULL,
		[FileData] varbinary(max) NULL,
		GoogleDriveUrl varchar(2000) NULL,
		FileHash binary(16) NULL,
		FileSize int NOT NULL DEFAULT 0,
		HiddenFromKB bit NOT NULL DEFAULT 0,
		HiddenFromTickets bit NOT NULL DEFAULT 0,
		AssetID int NULL,
		InstanceID int NOT NULL DEFAULT 0
)

CREATE TABLE dbo.DuplicateFiles (
	FileID int NOT NULL,
	CommentID int NOT NULL
)
ALTER TABLE DuplicateFiles WITH NOCHECK ADD
	CONSTRAINT [PK_DuplicateFiles] PRIMARY KEY CLUSTERED (FileID, CommentID)
GO


--ticket-to-ticket links
CREATE TABLE dbo.hdLinkedIssues (
	Issue1ID int NOT NULL,
	Issue2ID int NOT NULL
)
ALTER TABLE hdLinkedIssues WITH NOCHECK ADD 
	CONSTRAINT [PK_hdLinkedIssues] PRIMARY KEY CLUSTERED ([Issue1ID],[Issue2ID])
GO

--subtickets
CREATE TABLE dbo.hdSubIssues (
	ParentID int NOT NULL,
	ChildID int  NOT NULL PRIMARY KEY
)

--asset management tables
CREATE TABLE [dbo].[hdAssets] (
	ItemID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL,
	ModelName nvarchar(1000) NOT NULL,
	TypeID int NOT NULL,
	ManufacturerID int NOT NULL,
	Quantity int NOT NULL DEFAULT(0),
	SupplierID int NOT NULL,
	SerialNumber nvarchar(200) NULL,
	Location nvarchar(500) NULL,
	Comments nvarchar(1000) NULL,
	CompanyID int null,
	Disabled bit not null default(0)
)
CREATE TABLE [dbo].[hdAssetManufacturers] (
	ManufacturerID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL,
	[Name] nvarchar(1000) NOT NULL
)
CREATE TABLE [dbo].[hdAssetSuppliers] (
	SupplierID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL,
	[Name] nvarchar(1000) NOT NULL
)
CREATE TABLE [dbo].[hdAssetTypes] (
	TypeID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL,
	[Name] nvarchar(1000) NOT NULL
)
CREATE TABLE [dbo].[hdAssetUsers] (
	ItemID int NOT NULL,
	UserID int NOT NULL
)
ALTER TABLE [dbo].[hdAssetUsers] WITH NOCHECK ADD 
	CONSTRAINT [PK_hdAssetUsers] PRIMARY KEY CLUSTERED ([ItemID],[UserID])
GO


CREATE TABLE dbo.hdAssetsIssues	(
	IssueID int NOT NULL,
	AssetID int NOT NULL
) 
GO
ALTER TABLE [dbo].hdAssetsIssues WITH NOCHECK ADD 
	CONSTRAINT [PK_hdAssetsIssues] PRIMARY KEY CLUSTERED ([IssueID], [AssetID])
GO


CREATE TABLE dbo.TicketTemplates (
	CategoryID int NOT NULL PRIMARY KEY,
	[Subject] nvarchar(500) not null,
	Body nvarchar(max) not null
)
GO


CREATE TABLE [dbo].[Integrations] (
	[InstanceID] int NOT NULL PRIMARY KEY,
	BitbucketEnabled bit NOT NULL DEFAULT 0,
	BitbucketUsername varchar(50) null,
	BitbucketPassword varchar(50) null,
	HipChatEnabled bit NOT NULL DEFAULT 0,
	HipChatAuthToken varchar(50) null,
	HipChatRoomId int null,
	JiraEnabled bit NOT NULL DEFAULT 0,
	JiraUsername varchar(50) null,
	JiraPassword varchar(500) null,
	JiraUrl varchar(100) null,
	DropboxEnabled bit NOT NULL DEFAULT 0,
	DropboxAppID varchar(25) NULL,
	SlackEnabled bit NOT NULL DEFAULT 0,
	SlackWebhookURL varchar(100) null,
	GitHubEnabled bit not null default 0,
	GitHubUsername varchar(50) null,
	GitHubPassword varchar(50) null,
	GithubEnterpriseUrl varchar(100) null,
	UserLookupEnabled bit NOT NULL DEFAULT 0,
	UserLookupURL varchar(500) NULL,
	UserLookupBasicAuthEnabled bit NOT NULL DEFAULT 0,
	UserLookupUsername varchar(50) NULL,
	UserLookupPassword varchar(50) NULL,
	AsanaEnabled bit not null default 0,
	AsanaAccessToken varchar(300) null,
	AsanaRefreshToken varchar(300) null,
	TrelloEnabled bit not null default 0,
	VSOEnabled bit not null default 0,
	VSOAccountName varchar(50) null,
	VSOUsername varchar(50) null,
	VSOToken varchar(100) null,
	VSOSelfHosted bit NOT NULL DEFAULT 0,
	VSOCollectionName varchar(100) null,
	HarvestEnabled bit not null default 0,
	HarvestUsername varchar(50) null,
	HarvestPassword varchar(50) null,
	HarvestAccount varchar(50) null,
	ZapierEnabled bit not null default 0,
	GoogleDriveEnabled bit NOT NULL DEFAULT 0,
	HighriseEnabled bit NOT NULL DEFAULT 0,
	HighriseUrl varchar(150) NULL,
	HighriseToken varchar(50) NULL,
	GitLabEnabled bit not null default 0,
	GitLabToken varchar(50) NULL,
	SurveyMonkeyEnabled bit NOT NULL DEFAULT 0,
	SurveyMonkeyToken varchar(500) NULL,
	StripeEnabled bit not null default 0,
	GitHubToken varchar(50) NULL,
	StripeToken varchar(50) NULL,
	BasecampEnabled bit NOT NULL DEFAULT 0,
	BasecampToken varchar(1000) NULL,
	BasecampAccID varchar(50) NULL,
	MsTeamsEnabled bit NOT NULL DEFAULT 0,
	MsTeamsWebhookUrl varchar(500) NULL,
	GitLabBaseUrl varchar(100) null,
	OneDriveEnabled bit NOT NULL DEFAULT 0,
	BoxEnabled bit NOT NULL DEFAULT 0,
	TeamViewerEnabled bit NOT NULL DEFAULT 0,
	TeamViewerFieldID int NULL,
	ClickUpEnabled bit NOT NULL DEFAULT 0,
	ClieckUpToken varchar(80) NULL,
	WhatsAppEnabled bit NOT NULL DEFAULT 0,
	WhatsAppPhoneNumberId varchar(50) NULL,
	WhatsAppToken varchar(500) null,
	SnipeItEnabled bit NOT NULL DEFAULT 0,
	SnipeItUrl varchar(100) NULL,
	SnipeItToken varchar(1500) null,
	GPTEnabled bit NOT NULL DEFAULT 0,
	GPTApiKey varchar(100) NULL,
	GPTIncludeKB bit NOT NULL DEFAULT 0,
	LansweeperEnabled bit NOT NULL default 0,
	LansweeperToken varchar(200) NULL,
	LansweeperSiteId varchar(100) NULL
)
GO

CREATE TABLE dbo.PasswordPolicies (
	[InstanceID] int NOT NULL PRIMARY KEY,
	MinLength int NOT NULL DEFAULT 8,
	Uppercase bit NOT NULL DEFAULT 1,
	Lowercase bit NOT NULL DEFAULT 1,
	Numbers bit NOT NULL DEFAULT 1,
	SpecialChars bit NOT NULL DEFAULT 0
)

CREATE TABLE [dbo].[IntegrationTicketData] (
	IssueID int NOT NULL PRIMARY KEY,
	BitbucketIssueUrl varchar(300) null,
	JiraIssueUrl varchar(300) null,
	GitHubIssueUrl varchar(300) null,
	AsanaTaskUrl varchar(300) null,
	TrelloCardUrl varchar(300) null,
	VSOWorkItemUrl varchar(300) null,
	HarvestProjectUrl varchar(300) null,
	GitLabIssueUrl varchar(300) null,
	BasecampTodoUrl varchar(300) null,
	ClickUpTaskUrl varchar(300) null,
	SnipeItIds varchar(500) null,
	LansweeperIds varchar(1000) null
)
GO

CREATE TABLE [dbo].[OverdueLog] (
	IssueID int NOT NULL PRIMARY KEY,
	TimesOverDue int NOT NULL DEFAULT 1
)
GO

CREATE TABLE dbo.AutomationRules (
	RuleID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
	InstanceID int NOT NULL,
	RuleXml nvarchar(max),
	OrderByNumber int NOT NULL DEFAULT 1
)
GO



CREATE TABLE dbo.OverdueAutomationLog (
	IssueID int NOT NULL,
	RuleID int NOT NULL
)
GO
ALTER TABLE OverdueAutomationLog WITH NOCHECK ADD 
	CONSTRAINT [PK_OverdueAutomationLog] PRIMARY KEY CLUSTERED (IssueID, RuleID)
GO



CREATE TABLE dbo.NonupdatedAutomationLog (
	IssueID int NOT NULL,
	RuleID int NOT NULL
)
GO
ALTER TABLE NonupdatedAutomationLog WITH NOCHECK ADD 
	CONSTRAINT [PK_NonupdatedAutomationLog] PRIMARY KEY CLUSTERED (IssueID, RuleID)
GO

CREATE TABLE dbo.AutomationQueue (
	IssueID int NOT NULL,
	RuleID int NOT NULL
)
GO
ALTER TABLE AutomationQueue WITH NOCHECK ADD 
	CONSTRAINT [PK_AutomationQueue] PRIMARY KEY CLUSTERED (IssueID, RuleID)
GO

CREATE TABLE dbo.AutomationExecutionLog (
	RuleID int NOT NULL,
	CommentID int NOT NULL
)
GO
ALTER TABLE AutomationExecutionLog WITH NOCHECK ADD 
	CONSTRAINT [PK_AutomationExecutionLog] PRIMARY KEY CLUSTERED (RuleID, CommentID)
GO

CREATE TABLE [dbo].[DeletionLog]
(
	LogID int IDENTITY (1, 1) NOT NULL PRIMARY KEY,
    [InstanceID] INT NOT NULL, 
    [UserID] INT NOT NULL, 
    [Description] NVARCHAR(500) NOT NULL,
	[Date] [datetime] NOT NULL DEFAULT (getdate())
)

CREATE TABLE [dbo].[ZapierSubscriptions]
(
	[SubscriptionID] INT IDENTITY (1, 1) NOT NULL PRIMARY KEY, 
    [InstanceID] INT NOT NULL, 
    [EventID] INT NOT NULL, 
    [TargetURL] VARCHAR(500) NOT NULL
)

CREATE TABLE [dbo].[AssetLog] (
    [LogID]        INT           IDENTITY (1, 1) NOT NULL PRIMARY KEY,
    [ItemID]       INT           NOT NULL,
    [OriginatorID] INT           NOT NULL,
    [Description]  NVARCHAR (max) NOT NULL,
    [EntryDate]    DATETIME      DEFAULT (getdate()) NOT NULL
)

CREATE TABLE dbo.OneTimeChecks (
	CheckID varchar(50) NOT NULL PRIMARY KEY
)

--stored comments-issues before tickets ere merged
CREATE TABLE dbo.MergedComments (
	CommentID INT NOT NULL,
	IssueMergedID INT NOT NULL
)
ALTER TABLE MergedComments WITH NOCHECK ADD 
	CONSTRAINT [PK_MergedComments] PRIMARY KEY CLUSTERED (CommentID, IssueMergedID)
GO

--create default STATUSes DO NOT REMOVE!!!!!!!!!!!!!!!!
INSERT INTO hdStatus (Name) VALUES ('New')
go

INSERT INTO hdStatus (Name) VALUES ('In progress')
go

INSERT INTO hdStatus (Name) VALUES ('Resolved')
go

SET IDENTITY_INSERT hdStatus ON
INSERT INTO hdStatus (StatusID, Name) VALUES (-1, 'Deleted')
SET IDENTITY_INSERT hdStatus OFF
GO

--cut-- 
--create TWO PRE-DEFINED USERS
INSERT INTO hdUsers (username, email, password, IsAdministrator)
VALUES ('admin', 'admin@testmail', 'f99c5521e65bcf281a101f9aa73351179c8e4daf', 1)
GO

INSERT INTO hdUsers (username, email, password, IsAdministrator)
VALUES ('client', 'client@testmail', '3486ce5bf9f319c0458187ec31fe2496b08bdaae', 0)
GO

--create pre-defined sections
INSERT INTO hdSections (Name) VALUES ('Sales')
go

INSERT INTO hdSections (Name) VALUES ('Technical')
go

--create PRE-DEFINED CATEGORIES
INSERT INTO hdCategories (Name, SectionID) VALUES ('Bug reports', 2)
go

INSERT INTO hdCategories (Name, SectionID) VALUES ('Feature requests', 2)
go

INSERT INTO hdCategories (Name, SectionID) VALUES ('Hardware issues', 2)
go

INSERT INTO hdCategories (Name, SectionID) VALUES ('Other', 2)
go

INSERT INTO hdCategories (Name, SectionID) VALUES ('Payment issues', 1)
go

INSERT INTO hdCategories (Name, SectionID) VALUES ('Pre-sales questions', 1)
go

SET IDENTITY_INSERT Priorities ON
go
INSERT INTO Priorities (PriorityID, Name) VALUES (-1, 'Low')
go
INSERT INTO Priorities (PriorityID, Name) VALUES (0, 'Normal')
go
INSERT INTO Priorities (PriorityID, Name) VALUES (1, 'High')
go
INSERT INTO Priorities (PriorityID, Name) VALUES (2, 'Critical')
go
SET IDENTITY_INSERT Priorities OFF

--creating foreign keys
ALTER TABLE [dbo].[hdCategoryPermissions] ADD 
	CONSTRAINT [FK_hdCategoryPermissions_hdCategories] FOREIGN KEY([CategoryID]) REFERENCES [dbo].[hdCategories] ([CategoryID]),
	CONSTRAINT [FK_hdCategoryPermissions_hdUsers] FOREIGN KEY([UserID]) REFERENCES [dbo].[hdUsers] ([UserID])
GO

ALTER TABLE [dbo].[hdComments] ADD 
	CONSTRAINT [FK_hdComments_hdIssues] FOREIGN KEY([IssueID]) REFERENCES [dbo].[hdIssues] ([IssueID]),
	CONSTRAINT [FK_hdComments_hdUsers] FOREIGN KEY([UserID]) REFERENCES [dbo].[hdUsers] ([UserID])
GO

ALTER TABLE [dbo].[hdIssues] ADD 
	CONSTRAINT [FK_hdIssues_hdCategories] FOREIGN KEY([CategoryID]) REFERENCES [dbo].[hdCategories] ([CategoryID]),
	CONSTRAINT [FK_hdIssues_hdStatus] FOREIGN KEY([StatusID]) REFERENCES [dbo].[hdStatus] ([StatusID]),
	CONSTRAINT [FK_hdIssues_hdUsers1] FOREIGN KEY([UserID]) REFERENCES [dbo].[hdUsers] ([UserID]),
	CONSTRAINT [FK_hdIssues_hdUsers3] FOREIGN KEY([AssignedToUserID]) REFERENCES [dbo].[hdUsers] ([UserID])
GO

ALTER TABLE [dbo].[hdIssueSubscribers] ADD
	CONSTRAINT [FK_hdIssueSubscribers_hdIssues] FOREIGN KEY([IssueID]) REFERENCES [dbo].[hdIssues] ([IssueID]),
	CONSTRAINT [FK_hdIssueSubscribers_hdUsers] FOREIGN KEY([UserID]) REFERENCES [dbo].[hdUsers] ([UserID])
GO

--indexes
CREATE INDEX IX_hdComments_IssueID ON hdComments (IssueID)
CREATE INDEX IX_hdComments_UserID ON hdComments (UserID)
CREATE INDEX IX_hdIssues_CategoryID ON hdIssues (CategoryID)
CREATE INDEX IX_hdIssues_UserID ON hdIssues (UserID)
CREATE INDEX IX_hdIssues_StatusID ON hdIssues (StatusID)
CREATE INDEX IX_hdIssues_IssueDate ON hdIssues (IssueDate)
CREATE INDEX IX_hdIssues_AssignedToUserID ON hdIssues (AssignedToUserID)
CREATE INDEX IX_hdFileAttachments_IssueID ON hdFileAttachments (IssueID)
CREATE INDEX IX_hdFileAttachments_AssetID ON hdFileAttachments (AssetID)
CREATE INDEX IX_KBArticles_CategoryID ON KBArticles (CategoryID)
CREATE INDEX IX_hdCategoryPermissions_UserID ON hdCategoryPermissions (UserID)
CREATE INDEX IX_hdCustomFieldOptions_FieldID ON hdCustomFieldOptions (FieldID)
CREATE INDEX IX_hdUsers_CompanyID ON hdUsers (CompanyID)
CREATE INDEX IX_hdUsers_InstanceIDUsernameDisabled ON hdUsers (InstanceID, Username, [Disabled])
CREATE INDEX IX_hdUsers_InstanceIDEmailDisabled ON hdUsers (InstanceID, Email, [Disabled])
CREATE INDEX ix_hdAssets_ModelName ON [dbo].[hdAssets] ([ModelName])
CREATE INDEX ix_EmailTemplates_Cat ON EmailTemplates(CategoryID) WHERE CategoryID IS NOT NULL
CREATE INDEX IX_hdSubIssues_ParentID ON hdSubIssues (ParentID) INCLUDE (ChildID)
CREATE INDEX IX_hdIssues_UserIDIssueIDAssignedID ON [dbo].[hdIssues] (UserID,IssueID,AssignedToUserID)
CREATE INDEX IX_hdIssueTags_IssueID ON [dbo].[hdIssueTags] ([IssueID]) INCLUDE ([TagID])
CREATE INDEX IX_InstanceID_UsageType ON [dbo].[hdCustomFields] ([InstanceID],[UsageType])
CREATE INDEX IX_hdIssues_InstanceStatusAssigned_IncludeStatsFields ON [dbo].[hdIssues] ([InstanceID],[AssignedToUserID],[StatusID])
	INCLUDE ([IssueID],[UserID],[CategoryID],[UpdatedByUser],[UpdatedForTechView],[IssueDate],[ResolvedDate],[Subject],[UpdatedByPerformer],[Priority],[LastUpdated],[Origin],[DueDate],LastUpdatedByUserID)
CREATE INDEX ix_hdCustFIdVls_IssueID_incValue ON [dbo].[hdCustomFieldValues] ([IssueID]) INCLUDE ([Value],[FieldID])
CREATE INDEX IX_AutomationExecutionLog_RuleID ON AutomationExecutionLog (RuleID)

--create fulltextindexes
-- if fulltext components are installed
declare @installed sql_variant
select @installed=SERVERPROPERTY('IsFullTextInstalled')
IF(@installed = 1)
begin
	-- creating default catalog
	CREATE FULLTEXT CATALOG hdFulltextCatalog AS DEFAULT

	-- creating hdIssues index
	declare @constraint sysname

	SELECT @constraint=CONSTRAINT_NAME FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS WHERE TABLE_NAME='hdIssues' AND CONSTRAINT_TYPE='PRIMARY KEY'
	EXEC('CREATE FULLTEXT INDEX ON hdIssues ([FTS_Body] TYPE COLUMN [FTS_filetype]) KEY INDEX ' + @constraint)

	--hdComments index
	SELECT @constraint=CONSTRAINT_NAME FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS WHERE TABLE_NAME='hdComments' AND CONSTRAINT_TYPE='PRIMARY KEY'
	EXEC('CREATE FULLTEXT INDEX ON hdComments ([FTS_Body] TYPE COLUMN [FTS_filetype]) KEY INDEX ' + @constraint)

	--creating KB index
	SELECT @constraint=CONSTRAINT_NAME FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS WHERE TABLE_NAME='KBArticles' AND CONSTRAINT_TYPE='PRIMARY KEY'
	EXEC('CREATE FULLTEXT INDEX ON KBArticles (Subject, [Body]) KEY INDEX ' + @constraint)

	--creating CF index
	SELECT @constraint=CONSTRAINT_NAME FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS WHERE TABLE_NAME='hdCustomFieldTextValues' AND CONSTRAINT_TYPE='PRIMARY KEY'
	EXEC(N'CREATE FULLTEXT INDEX ON hdCustomFieldTextValues (CustomFieldsText) KEY INDEX ' + @constraint)
end