﻿function InitTooltip(popupSelector, targetSelector, progressImageUrl, ajaxUrl) {
	//init cache dictionaries
	window.userPopupCache = window.userPopupCache || {};
	window.userPopupCache[popupSelector] = window.userPopupCache[popupSelector] || {};

	var $popup = $(popupSelector);

	var template = $popup.html();
	template = template.replace( /%7B/g , "{").replace( /%7D/g , "}"); // to fix stupid Firefox encoding

	$(targetSelector).prop('title', 'Click to preview in a pop-up');

	$(document).on("click", targetSelector, function (e) {
		e.preventDefault();

		var username = $(this).attr("data-username"); //get username from the clicked element. We do not return it from the server to prevent email exposures
		if (!username)
			username = $(this).text();

		$("html").unbind('click.hidepopup');
		var linkPosition = $(this).offset();
		var popupLeftCoord = linkPosition.left;

		var wndWidth = $(window).width();
		var popupWidth = $popup.outerWidth() + 10;
		if (linkPosition.left + popupWidth > wndWidth) popupLeftCoord = wndWidth - popupWidth;

		var id = $(this).attr("data-userid");
		if (id && id > 0) {
			$popup.html("<img src='" + progressImageUrl + "' style='margin-left: 48%;' /><b class='border-notch notch'></b><b class='notch'></b>");
			$popup.show().offset({ top: linkPosition.top + 25, left: popupLeftCoord });

			var cacheDict = window.userPopupCache[popupSelector];
			if (cacheDict[id]) { //found in cache?
				showPopup(cacheDict[id]);
				return;
			}

			$.ajax({
				type: "POST",
				url: ajaxUrl + "/" + id,
				dataType: "json",
				success: function(msg) {
					var userObj = msg; // json object returned from server
					msg.Username = username;
					userObj.NameSpecified = (userObj.FirstName || userObj.LastName);
					userObj.NotesWithClickableLinks = convertToLink(userObj.Notes);
					if (userObj.RecentTickets) { //color-coding by status
						for (i = 0; i < userObj.RecentTickets.length; i++) {
							var t = userObj.RecentTickets[i];
							t.cssclass = t.StatusID == 1 ? "new-badge" : t.StatusID == 3 ? "closed-badge" : t.UpdatedByUser ? "cust-badge" : t.UpdatedByPerformer ? "tech-badge" : "";
							t.StatusName = t.StatusID == 1 ? _langStrings.New : t.StatusID == 3 ? _langStrings.StatusClosed : t.UpdatedByUser ? _langStrings.UpdByCust : t.UpdatedByPerformer ? _langStrings.UpdByTech : "";
							if (t.StatusID == 1) t.cssclass = "new-badge";
							if (t.StatusID == -1) t.cssclass = "closed-badge";
						}
					}

					cacheDict[id] = userObj; //save to cache
					showPopup(userObj);
				}
			});

			function showPopup(userObj) {
				var markup = Mustache.render(template, userObj);
				$popup.html(markup);
				$popup.find("#userPopupAvatar").attr("src", userObj.AvatarURL); //had to set image src for avatar separately to avoid annoying 404 error

				$("html").bind('click.hidepopup', function () {
					if ($popup.is(':visible')) $popup.hide();
					$("html").unbind('click.hidepopup');
				});
				$popup.click(function (e) { e.stopPropagation(); });

				window.addEventListener("keydown", function handler(e) { //close on ESC for acessibility
					if (e.keyCode == 27) {
						$(".userPopup").hide();
						window.removeEventListener("keydown", handler);
					}
				});

				//move notch to click loction
				var $notch = $popup.children(".notch");
				$notch.css('left', (linkPosition.left - popupLeftCoord + 10) + 'px');

				//user lookup data
				if ($popup.find("#popupLookup").length) {
					LoadUserLookup(ajaxUrl.substring(0, ajaxUrl.indexOf("User/UserInfoJson")), userObj.Email, $("#popupLookup"));
				}

				Utils.addCopyButton();
			}
		}
	});
}

function LoadUserLookup(hdUrl, email, $targetElement) {
	if (hdUrl[hdUrl.length - 1] != '/') hdUrl += "/";
	$.get(hdUrl + "User/GetLookupData?email=" + email, function (data) {
		try {
			var parsedData = JSON.parse(data); //is it JSON?
			if (Object.keys(parsedData).length > 0) {
				$targetElement.html(JsonHuman.format(parsedData, { showArrayIndex: false })).show();
			}
			else
				$targetElement.html("");
		} catch (e) { //probably HTML
			if (data) {
				$targetElement.html(data).show();
			}
		}
	});
}

function SaveUserNotes(ajaxUrl, userId) {
	$.post(ajaxUrl, { userId: userId, notes: $('#txtUserNotes').val() });
	$('#divEditNotes').slideUp();
	$('#spanNotes').html(convertToLink($('#txtUserNotes').val()));
	$('#spanNotes').show();
	$('#lnkEditNotes').show();
	window.userPopupCache["#userPopup"] = {}; //reset all cache
}